@@ -13,15 +13,15 @@
 ##############################################################################
 """API for working installing things on startup.
 
-$Id: interfaces.py 113108 2010-06-04 11:53:16Z janwijbrand $
+$Id$
 """
 # BBB imports
 from zope.processlifetime import IDatabaseOpened
-from zope.processlifetime import DatabaseOpened
+from zope.processlifetime import DatabaseOpened  # noqa: F401
 from zope.processlifetime import IDatabaseOpenedWithRoot
-from zope.processlifetime import DatabaseOpenedWithRoot
+from zope.processlifetime import DatabaseOpenedWithRoot  # noqa: F401
 from zope.processlifetime import IProcessStarting
-from zope.processlifetime import ProcessStarting
+from zope.processlifetime import ProcessStarting  # noqa: F401
 
 # BBB aliases
 IDatabaseOpenedEvent = IDatabaseOpened
