@@ -11,26 +11,26 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Bootstrap tests
-
-$Id: tests.py 116897 2010-09-25 13:11:48Z icemac $
-"""
+"""Bootstrap tests"""
 import ZConfig
 import doctest
 import os
 import sys
+import re
 import transaction
 import unittest
-import urllib
+try:
+    from urllib.request import pathname2url
+except ImportError:
+    from urllib import pathname2url
 
 import zope.component
 
-from ZODB.tests.util import DB
+from ZODB.MappingStorage import DB
 from zope.traversing.api import traverse, getPath
 from zope.error.interfaces import IErrorReportingUtility
 from zope.error.error import ErrorReportingUtility
 
-from zope.site import hooks
 from zope.site.folder import rootFolder, Folder
 from zope.site.interfaces import IRootFolder
 from zope.app.publication.zopepublication import ZopePublication
@@ -38,27 +38,29 @@ from zope.site.site import LocalSiteManager
 
 import zope.app.appsetup
 from zope.app.appsetup.bootstrap import bootStrapSubscriber
-from zope.app.appsetup.bootstrap import getInformationFromEvent, \
-     ensureObject, ensureUtility
+from zope.app.appsetup.bootstrap import getInformationFromEvent, ensureUtility
 from zope.processlifetime import DatabaseOpened
-from zope.app.appsetup.errorlog import bootStrapSubscriber as errorlogBootStrapSubscriber
-from zope.app.appsetup.session import bootStrapSubscriber as sessionBootstrapSubscriber
+from zope.app.appsetup.errorlog import bootStrapSubscriber as errorlogBootStrapSubscriber  # noqa: E501
+from zope.app.appsetup.session import bootStrapSubscriber as sessionBootstrapSubscriber  # noqa: E501
 from zope.session.interfaces import IClientIdManager
 from zope.session.interfaces import ISessionDataContainer
+from zope.testing import renormalizing
 
 from zope.component.testlayer import ZCMLFileLayer
 
 layer = ZCMLFileLayer(zope.app.appsetup)
 
+
 class EventStub(object):
 
     def __init__(self, db):
         self.database = db
 
 #
-# TODO: some methods from the boostap module are not tested
+# TODO: some methods from the bootstrap module are not tested
 #
 
+
 class TestBootstrapSubscriber(unittest.TestCase):
 
     layer = layer
@@ -101,9 +103,9 @@ class TestBootstrapSubscriber(unittest.TestCase):
         cx = self.db.open()
         root = cx.root()
         root_folder = root.get(ZopePublication.root_name, None)
-        self.assert_(IRootFolder.providedBy(root_folder))
+        self.assertTrue(IRootFolder.providedBy(root_folder))
         package_name = '/++etc++site/default'
-        package = traverse(root_folder, package_name)
+        traverse(root_folder, package_name)
         cx.close()
 
     def test_ensureUtilityForSubSite(self):
@@ -114,15 +116,16 @@ class TestBootstrapSubscriber(unittest.TestCase):
 
         sub_folder = root_folder['sub_folder']
         ensureUtility(sub_folder, IErrorReportingUtility,
-                     'ErrorReporting', ErrorReportingUtility,
-                     'ErrorReporting')
+                      'ErrorReporting', ErrorReportingUtility,
+                      'ErrorReporting')
 
         # Make sure it was created on the sub folder, not the root folder
         got_utility = zope.component.getUtility(IErrorReportingUtility,
                                                 name='ErrorReporting',
                                                 context=sub_folder)
         got_path = getPath(got_utility)
-        self.assertEquals("/sub_folder/++etc++site/default/ErrorReporting", got_path)
+        self.assertEqual(
+            "/sub_folder/++etc++site/default/ErrorReporting", got_path)
 
     def test_ensureUtility(self):
         self.createRFAndSM()
@@ -140,7 +143,7 @@ class TestBootstrapSubscriber(unittest.TestCase):
             utility2 = ensureUtility(root_folder, IErrorReportingUtility,
                                      'ErrorReporting2', ErrorReportingUtility,
                                      'ErrorReporting2')
-            if utility != None:
+            if utility is not None:
                 name = utility.__name__
                 name2 = utility2.__name__
             else:
@@ -159,9 +162,9 @@ class TestBootstrapSubscriber(unittest.TestCase):
             package_name = '/++etc++site/default'
             package = traverse(self.root_folder, package_name)
 
-            self.assert_(IErrorReportingUtility.providedBy(
+            self.assertTrue(IErrorReportingUtility.providedBy(
                 traverse(package, 'ErrorReporting')))
-            self.assert_(IErrorReportingUtility.providedBy(
+            self.assertTrue(IErrorReportingUtility.providedBy(
                 traverse(package, 'ErrorReporting2')))
             transaction.commit()
 
@@ -183,7 +186,7 @@ class TestBootstrapSubscriber(unittest.TestCase):
 
         got_utility = zope.component.getUtility(IErrorReportingUtility,
                                                 context=root_folder)
-        self.failUnless(IErrorReportingUtility.providedBy(got_utility))
+        self.assertTrue(IErrorReportingUtility.providedBy(got_utility))
         # we need to close again in the end
         connection.close()
 
@@ -198,11 +201,11 @@ class TestBootstrapSubscriber(unittest.TestCase):
 
         got_utility = zope.component.getUtility(IClientIdManager,
                                                 context=root_folder)
-        self.failUnless(IClientIdManager.providedBy(got_utility))
+        self.assertTrue(IClientIdManager.providedBy(got_utility))
 
         got_utility = zope.component.getUtility(ISessionDataContainer,
                                                 context=root_folder)
-        self.failUnless(ISessionDataContainer.providedBy(got_utility))
+        self.assertTrue(ISessionDataContainer.providedBy(got_utility))
 
         # we need to close again in the end
         connection.close()
@@ -215,7 +218,7 @@ class TestConfigurationSchema(unittest.TestCase):
         self.schema_dir = os.path.join(self.here, "schema")
 
     def path2url(self, path):
-        urlpath = urllib.pathname2url(path)
+        urlpath = pathname2url(path)
         while urlpath.startswith("/"):
             urlpath = urlpath[1:]
         return "file:///" + urlpath
@@ -223,13 +226,12 @@ class TestConfigurationSchema(unittest.TestCase):
     def test_productconfig_xml(self):
         path = os.path.join(self.schema_dir, "productconfig.xml")
         url = self.path2url(path)
-        schema = ZConfig.loadSchema(url)
+        ZConfig.loadSchema(url)
 
     def test_schema_xml(self):
         path = os.path.join(self.schema_dir, "schema.xml")
         url = self.path2url(path)
-        schema = ZConfig.loadSchema(url)
-
+        ZConfig.loadSchema(url)
 
 
 class DebugLayer(ZCMLFileLayer):
@@ -262,12 +264,24 @@ def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TestBootstrapSubscriber))
     suite.addTest(unittest.makeSuite(TestConfigurationSchema))
-    for module in ['zope.app.appsetup.appsetup',]:
-        test = doctest.DocTestSuite(module)
-        test.layer = layer
-        suite.addTest(test)
-    for filename in ['bootstrap.txt', 'product.txt',]:
-        test = doctest.DocFileSuite(filename)
+
+    rules = [
+        (re.compile("u('.*?')"), r"\1"),
+        (re.compile('u(".*?")'), r"\1"),
+    ]
+    checker = renormalizing.RENormalizing(rules)
+    dtflags = (
+        doctest.ELLIPSIS
+        | doctest.NORMALIZE_WHITESPACE
+        | doctest.REPORT_NDIFF)
+
+    test = doctest.DocTestSuite('zope.app.appsetup.appsetup')
+    test.layer = layer
+    suite.addTest(test)
+    for filename in ['bootstrap.txt', 'product.txt']:
+        test = doctest.DocFileSuite(filename,
+                                    optionflags=dtflags,
+                                    checker=checker)
         test.layer = layer
         suite.addTest(test)
 
@@ -276,11 +290,6 @@ def test_suite():
     suite.addTest(test)
     suite.addTest(doctest.DocFileSuite(
         'testlayer.txt',
-         optionflags=(doctest.ELLIPSIS +
-                      doctest.NORMALIZE_WHITESPACE +
-                      doctest.REPORT_NDIFF)))
+        optionflags=dtflags))
 
     return suite
-
-if __name__ == '__main__':
-    unittest.main()
